@@ -10,12 +10,13 @@ typedef  OP *(*OPAnnotationPPAddr)(pTHX);
 typedef void (*OPAnnotationDtor)(pTHX_ void *data);
 
 typedef struct {
-    void *data;
     OPAnnotationPPAddr ppaddr;
+    void *data;
+    OPAnnotationDtor dtor;
 } OPAnnotation;
 
-OPAnnotationGroup op_annotation_group_new(OPAnnotationDtor dtor);
-OPAnnotation * op_annotation_new(OPAnnotationGroup group, OPAnnotationPPAddr ppaddr, void *data);
+OPAnnotationGroup op_annotation_group_new();
+OPAnnotation * op_annotation_new(OPAnnotationGroup group, OPAnnotationPPAddr ppaddr, void *data, OPAnnotationDtor dtor);
 void op_annotation_group_free(OPAnnotationGroup group);
 void op_annotation_free(OPAnnotation *annotation);
 
